package sun.misc;

import java.io.OutputStreamWriter;
import java.io.FileWriter;
import java.io.File;
import java.security.PrivilegedAction;
import java.security.AccessController;
import sun.security.action.GetPropertyAction;
import java.io.Writer;
import java.util.Vector;

public class PerformanceLogger
{
    private static final int START_INDEX = 0;
    private static final int LAST_RESERVED = 0;
    private static boolean perfLoggingOn;
    private static boolean useNanoTime;
    private static Vector<PerformanceLogger.TimeData> times;
    private static String logFileName;
    private static Writer logWriter;
    private static long baseTime;
    
    public PerformanceLogger() {
    }
    
    public static boolean loggingEnabled() {
        return PerformanceLogger.perfLoggingOn;
    }
    
    private static long getCurrentTime() {
        if (PerformanceLogger.useNanoTime) {
            return System.nanoTime();
        }
        return System.currentTimeMillis();
    }
    
    public static void setStartTime(String s) {
        if (loggingEnabled()) {
            setStartTime(s, getCurrentTime());
        }
    }
    
    public static void setBaseTime(long baseTime) {
        if (loggingEnabled()) {
            PerformanceLogger.baseTime = baseTime;
        }
    }
    
    public static void setStartTime(String s, long n) {
        if (loggingEnabled()) {
            PerformanceLogger.times.set(0, new PerformanceLogger.TimeData(s, n));
        }
    }
    
    public static long getStartTime() {
        if (loggingEnabled()) {
            return ((PerformanceLogger.TimeData)PerformanceLogger.times.get(0)).getTime();
        }
        return 0L;
    }
    
    public static int setTime(String s) {
        if (loggingEnabled()) {
            return setTime(s, getCurrentTime());
        }
        return 0;
    }
    
    public static int setTime(String s, long n) {
        if (loggingEnabled()) {
            synchronized (PerformanceLogger.times) {
                PerformanceLogger.times.add(new PerformanceLogger.TimeData(s, n));
                return PerformanceLogger.times.size() - 1;
            }
        }
        return 0;
    }
    
    public static long getTimeAtIndex(int index) {
        if (loggingEnabled()) {
            return ((PerformanceLogger.TimeData)PerformanceLogger.times.get(index)).getTime();
        }
        return 0L;
    }
    
    public static String getMessageAtIndex(int index) {
        if (loggingEnabled()) {
            return ((PerformanceLogger.TimeData)PerformanceLogger.times.get(index)).getMessage();
        }
        return null;
    }
    
    public static void outputLog(Writer obj) {
        if (loggingEnabled()) {
            try {
                synchronized (PerformanceLogger.times) {
                    for (int i = 0; i < PerformanceLogger.times.size(); ++i) {
                        PerformanceLogger.TimeData timeData = (PerformanceLogger.TimeData)PerformanceLogger.times.get(i);
                        if (timeData != null) {
                            obj.write(i + " " + timeData.getMessage() + ": " + (timeData.getTime() - PerformanceLogger.baseTime) + "\n");
                        }
                    }
                }
                obj.flush();
            }
            catch (Exception obj2) {
                System.out.println(obj2 + ": Writing performance log to " + obj);
            }
        }
    }
    
    public static void outputLog() {
        outputLog(PerformanceLogger.logWriter);
    }
    
    static {
        PerformanceLogger.perfLoggingOn = false;
        PerformanceLogger.useNanoTime = false;
        PerformanceLogger.logFileName = null;
        PerformanceLogger.logWriter = null;
        String s = (String)AccessController.doPrivileged(new GetPropertyAction("sun.perflog"));
        if (s != null) {
            PerformanceLogger.perfLoggingOn = true;
            if ((String)AccessController.doPrivileged(new GetPropertyAction("sun.perflog.nano")) != null) {
                PerformanceLogger.useNanoTime = true;
            }
            if (s.regionMatches(true, 0, "file:", 0, 5)) {
                PerformanceLogger.logFileName = s.substring(5);
            }
            if (PerformanceLogger.logFileName != null && PerformanceLogger.logWriter == null) {
                AccessController.doPrivileged(new PrivilegedAction<Void>() {
                    @Override
                    public Void run() {
                        try {
                            File file = new File(PerformanceLogger.logFileName);
                            file.createNewFile();
                            PerformanceLogger.logWriter = new FileWriter(file);
                        }
                        catch (Exception obj) {
                            System.out.println(obj + ": Creating logfile " + PerformanceLogger.logFileName + ".  Log to console");
                        }
                        return null;
                    }
                });
            }
            if (PerformanceLogger.logWriter == null) {
                PerformanceLogger.logWriter = new OutputStreamWriter(System.out);
            }
        }
        PerformanceLogger.times = new Vector(10);
        for (int i = 0; i <= 0; ++i) {
            PerformanceLogger.times.add(new PerformanceLogger.TimeData("Time " + i + " not set", 0L));
        }
    }
    
    static class TimeData
    {
        String message;
        long time;
        
        TimeData(String message, long time) {
            this.message = message;
            this.time = time;
        }
        
        String getMessage() {
            return this.message;
        }
        
        long getTime() {
            return this.time;
        }
    }
}
